"""empty message

Revision ID: e0117f63ca57
Revises: fc8b9a0a819c
Create Date: 2023-12-16 16:38:58.174130

"""
from alembic import op
import sqlalchemy as sa


# revision identifiers, used by Alembic.
revision = 'e0117f63ca57'
down_revision = 'fc8b9a0a819c'
branch_labels = None
depends_on = None


def upgrade() -> None:
    # ### commands auto generated by Alembic - please adjust! ###
    op.drop_constraint('filepaths_un', 'filepaths', schema='fansly', type_='unique')
    op.create_unique_constraint(None, 'filepaths', ['message_id', 'media_id'], schema='fansly')
    op.create_unique_constraint(None, 'filepaths', ['mass_message_id', 'media_id'], schema='fansly')
    op.create_unique_constraint(None, 'filepaths', ['post_id', 'media_id'], schema='fansly')
    op.create_unique_constraint(None, 'filepaths', ['story_id', 'media_id'], schema='fansly')
    op.create_unique_constraint(None, 'filepaths', ['post_id', 'media_id'], schema='onlyfans')
    op.create_unique_constraint(None, 'filepaths', ['message_id', 'media_id'], schema='onlyfans')
    op.create_unique_constraint(None, 'filepaths', ['mass_message_id', 'media_id'], schema='onlyfans')
    op.create_unique_constraint(None, 'filepaths', ['story_id', 'media_id'], schema='onlyfans')
    # ### end Alembic commands ###


def downgrade() -> None:
    # ### commands auto generated by Alembic - please adjust! ###
    op.drop_constraint(None, 'filepaths', schema='onlyfans', type_='unique')
    op.drop_constraint(None, 'filepaths', schema='onlyfans', type_='unique')
    op.drop_constraint(None, 'filepaths', schema='onlyfans', type_='unique')
    op.drop_constraint(None, 'filepaths', schema='onlyfans', type_='unique')
    op.drop_constraint(None, 'filepaths', schema='fansly', type_='unique')
    op.drop_constraint(None, 'filepaths', schema='fansly', type_='unique')
    op.drop_constraint(None, 'filepaths', schema='fansly', type_='unique')
    op.drop_constraint(None, 'filepaths', schema='fansly', type_='unique')
    op.create_unique_constraint('filepaths_un', 'filepaths', ['story_id', 'post_id', 'message_id', 'mass_message_id', 'media_id'], schema='fansly')
    # ### end Alembic commands ###
