"""empty message

Revision ID: bc4b94108111
Revises: e0117f63ca57
Create Date: 2023-12-16 16:53:24.055048

"""
from alembic import op
import sqlalchemy as sa


# revision identifiers, used by Alembic.
revision = 'bc4b94108111'
down_revision = 'e0117f63ca57'
branch_labels = None
depends_on = None


def upgrade() -> None:
    # ### commands auto generated by Alembic - please adjust! ###
    op.drop_constraint('content_media_asso_story_id_post_id_message_id_mass_message_key', 'content_media_asso', schema='fansly', type_='unique')
    op.create_unique_constraint(None, 'content_media_asso', ['story_id', 'media_id'], schema='fansly')
    op.create_unique_constraint(None, 'content_media_asso', ['message_id', 'media_id'], schema='fansly')
    op.create_unique_constraint(None, 'content_media_asso', ['post_id', 'media_id'], schema='fansly')
    op.create_unique_constraint(None, 'content_media_asso', ['mass_message_id', 'media_id'], schema='fansly')
    op.drop_constraint('content_media_asso_story_id_post_id_message_id_mass_message_key', 'content_media_asso', schema='onlyfans', type_='unique')
    op.create_unique_constraint(None, 'content_media_asso', ['story_id', 'media_id'], schema='onlyfans')
    op.create_unique_constraint(None, 'content_media_asso', ['post_id', 'media_id'], schema='onlyfans')
    op.create_unique_constraint(None, 'content_media_asso', ['message_id', 'media_id'], schema='onlyfans')
    op.create_unique_constraint(None, 'content_media_asso', ['mass_message_id', 'media_id'], schema='onlyfans')
    # ### end Alembic commands ###


def downgrade() -> None:
    # ### commands auto generated by Alembic - please adjust! ###
    op.drop_constraint(None, 'content_media_asso', schema='onlyfans', type_='unique')
    op.drop_constraint(None, 'content_media_asso', schema='onlyfans', type_='unique')
    op.drop_constraint(None, 'content_media_asso', schema='onlyfans', type_='unique')
    op.drop_constraint(None, 'content_media_asso', schema='onlyfans', type_='unique')
    op.create_unique_constraint('content_media_asso_story_id_post_id_message_id_mass_message_key', 'content_media_asso', ['story_id', 'post_id', 'message_id', 'mass_message_id', 'media_id'], schema='onlyfans')
    op.drop_constraint(None, 'content_media_asso', schema='fansly', type_='unique')
    op.drop_constraint(None, 'content_media_asso', schema='fansly', type_='unique')
    op.drop_constraint(None, 'content_media_asso', schema='fansly', type_='unique')
    op.drop_constraint(None, 'content_media_asso', schema='fansly', type_='unique')
    op.create_unique_constraint('content_media_asso_story_id_post_id_message_id_mass_message_key', 'content_media_asso', ['story_id', 'post_id', 'message_id', 'mass_message_id', 'media_id'], schema='fansly')
    # ### end Alembic commands ###
