"""empty message

Revision ID: ead3644aab16
Revises: fada8d5e0210
Create Date: 2023-12-16 15:47:28.103237

"""
from alembic import op
import sqlalchemy as sa


# revision identifiers, used by Alembic.
revision = 'ead3644aab16'
down_revision = 'fada8d5e0210'
branch_labels = None
depends_on = None


def upgrade() -> None:
    # ### commands auto generated by Alembic - please adjust! ###
    op.create_index('filepaths_un', 'filepaths', ['story_id', 'post_id', 'message_id', 'mass_message_id', 'media_id'], unique=True, schema='fansly', postgresql_where='(story_id IS NOT NULL) OR (post_id IS NOT NULL) OR (message_id IS NOT NULL) OR (mass_message_id IS NOT NULL) OR (media_id IS NOT NULL)')
    op.create_index('filepaths_un', 'filepaths', ['story_id', 'post_id', 'message_id', 'mass_message_id', 'media_id'], unique=True, schema='onlyfans', postgresql_where='(story_id IS NOT NULL) OR (post_id IS NOT NULL) OR (message_id IS NOT NULL) OR (mass_message_id IS NOT NULL) OR (media_id IS NOT NULL)')
    # ### end Alembic commands ###


def downgrade() -> None:
    # ### commands auto generated by Alembic - please adjust! ###
    op.drop_index('filepaths_un', table_name='filepaths', schema='onlyfans', postgresql_where='(story_id IS NOT NULL) OR (post_id IS NOT NULL) OR (message_id IS NOT NULL) OR (mass_message_id IS NOT NULL) OR (media_id IS NOT NULL)')
    op.drop_index('filepaths_un', table_name='filepaths', schema='fansly', postgresql_where='(story_id IS NOT NULL) OR (post_id IS NOT NULL) OR (message_id IS NOT NULL) OR (mass_message_id IS NOT NULL) OR (media_id IS NOT NULL)')
    # ### end Alembic commands ###
