"""empty message

Revision ID: fada8d5e0210
Revises: 86985996f9b9
Create Date: 2023-12-14 12:08:53.519490

"""
from alembic import op
import sqlalchemy as sa


# revision identifiers, used by Alembic.
revision = 'fada8d5e0210'
down_revision = '86985996f9b9'
branch_labels = None
depends_on = None


def upgrade() -> None:
    # ### commands auto generated by Alembic - please adjust! ###
    op.create_table('favorite_users',
    sa.Column('id', sa.Integer(), nullable=False),
    sa.Column('user_id', sa.BigInteger(), nullable=False),
    sa.Column('notification', sa.Boolean(), server_default='true', nullable=False),
    sa.ForeignKeyConstraint(['user_id'], ['fansly.users.id'], ),
    sa.PrimaryKeyConstraint('id'),
    sa.UniqueConstraint('user_id'),
    schema='fansly'
    )
    op.create_table('favorite_users',
    sa.Column('id', sa.Integer(), nullable=False),
    sa.Column('user_id', sa.BigInteger(), nullable=False),
    sa.Column('notification', sa.Boolean(), server_default='true', nullable=False),
    sa.ForeignKeyConstraint(['user_id'], ['onlyfans.users.id'], ),
    sa.PrimaryKeyConstraint('id'),
    sa.UniqueConstraint('user_id'),
    schema='onlyfans'
    )
    op.add_column('jobs', sa.Column('priority', sa.Boolean(), server_default='false', nullable=False), schema='fansly')
    op.add_column('jobs', sa.Column('priority', sa.Boolean(), server_default='false', nullable=False), schema='onlyfans')
    # ### end Alembic commands ###


def downgrade() -> None:
    # ### commands auto generated by Alembic - please adjust! ###
    op.drop_column('jobs', 'priority', schema='onlyfans')
    op.drop_column('jobs', 'priority', schema='fansly')
    op.drop_table('favorite_users', schema='onlyfans')
    op.drop_table('favorite_users', schema='fansly')
    # ### end Alembic commands ###
